diff --git a/extdbms/lib/Configs/Constant.php b/extdbms/lib/Configs/Constant.php
index b62fb39..d43e43f 100644
--- a/extdbms/lib/Configs/Constant.php
+++ b/extdbms/lib/Configs/Constant.php
@@ -46,3 +46,40 @@ define('DBMS_SITEINFOS', [
],
]
]);
+define('DBMS_SERVICE_SWITCHCODE', [
+ 'Chiba' => ['begin' => 'C00%', 'end' => 'C64%'],
+ 'Tokyo' => ['begin' => 'C80%', 'end' => 'C99%']
+]);
+define('DBMS_SERVICE_LINE', [
+ 'normal' => '일반',
+ 'defence' => '방어',
+ 'solo' => '전용',
+ 'substitution' => '대체',
+ 'test' => '테스트',
+ 'vpn' => 'VPN',
+ 'event' => '이벤트',
+]);
+define('DBMS_SERVICE_STATUS', [
+ 'o' => '정상',
+ 'x' => '정지',
+ 's' => '정지예정',
+ 'c' => '취소',
+]);
+define('DBMS_SERVICE_STATUS_COLOR', [
+ 'o' => 'success',
+ 'x' => 'danger',
+ 's' => 'warning',
+ 'c' => 'info',
+]);
+define('DBMS_SERVICE_STATUS_TEXT', [
+ 'o' => '정상',
+ 'x' => '정지',
+ 's' => '정지예정',
+ 'c' => '취소',
+]);
+define('DBMS_SERVICE_STATUS_TEXT_COLOR', [
+ 'o' => 'success',
+ 'x' => 'danger',
+ 's' => 'warning',
+ 'c' => 'info',
+]);
diff --git a/extdbms/lib/Controllers/DBMS/CouponController.php b/extdbms/lib/Controllers/DBMS/CouponController.php
index e058a8b..f8dcb54 100644
--- a/extdbms/lib/Controllers/DBMS/CouponController.php
+++ b/extdbms/lib/Controllers/DBMS/CouponController.php
@@ -10,9 +10,8 @@ class CouponController extends BaseController
$this->getView()->setPath('coupon');
} //
- //Dashboard , default_alert.php
- //CLI 접속방법 : php index.php SiteController/dashboard
- //WEB 접속방법 : http://localhost/SiteController/dashboard
+ //CLI 접속방법 : php index.php site/counpon
+ //WEB 접속방법 : http://localhost/site/coupon
public function index()
{
return $this->render(__FUNCTION__);
diff --git a/extdbms/lib/Controllers/DBMS/NavigatorController.php b/extdbms/lib/Controllers/DBMS/NavigatorController.php
index 64894f3..e744952 100644
--- a/extdbms/lib/Controllers/DBMS/NavigatorController.php
+++ b/extdbms/lib/Controllers/DBMS/NavigatorController.php
@@ -24,8 +24,8 @@ class NavigatorController extends BaseController
}
//부가서비스 : 닷디펜더,딥파인더 등, deepfinder_list.php,dotdefender_list.php
- //CLI 접속방법 : php index.php SiteController/extraservice/client_code/코드번호
- //WEB 접속방법 : http://localhost/SiteController/extraservice/sitekey/dbms.prime-idc.jp/client_code/코드번호
+ //CLI 접속방법 : php index.php site/navigator//ipsearch
+ //WEB 접속방법 : http://localhost/site/navigator/ipsearch
public function ipsearch(): string
{
//전체 고객정보
diff --git a/extdbms/lib/Controllers/DBMS/PaymentController.php b/extdbms/lib/Controllers/DBMS/PaymentController.php
index dc2b025..e423219 100644
--- a/extdbms/lib/Controllers/DBMS/PaymentController.php
+++ b/extdbms/lib/Controllers/DBMS/PaymentController.php
@@ -20,9 +20,9 @@ class PaymentController extends BaseController
return $this->_clientService;
}
- //부가서비스 : 닷디펜더,딥파인더 등, deepfinder_list.php,dotdefender_list.php
- //CLI 접속방법 : php index.php SiteController/extraservice/client_code/코드번호
- //WEB 접속방법 : http://localhost/SiteController/extraservice/sitekey/dbms.prime-idc.jp/client_code/코드번호
+ //청구서
+ //CLI 접속방법 : php index.php site/payment/billpaper/sitekey/도메인/client_code/코드번호
+ //WEB 접속방법 : http://localhost/site/payment/billpaper/sitekey/도메인/client_code/코드번호
public function billpaper(mixed $sitekey = null, mixed $client_code = null): string
{
if ($sitekey === null) {
diff --git a/extdbms/lib/Services/HistoryService.php b/extdbms/lib/Services/HistoryService.php
index 1f9653b..b45b49e 100644
--- a/extdbms/lib/Services/HistoryService.php
+++ b/extdbms/lib/Services/HistoryService.php
@@ -27,7 +27,7 @@ class HistoryService extends CommonService
{
return Entity::class;
}
- public function getNews(int $limit = 5): array
+ public function getLatest(int $limit = 5): array
{
$this->getModel()->orderBy($this->getModel()->getPKField(), 'DESC');
$this->getModel()->limit($limit);
diff --git a/extdbms/lib/Services/ServiceService.php b/extdbms/lib/Services/ServiceService.php
index baf7f1c..f2d829b 100644
--- a/extdbms/lib/Services/ServiceService.php
+++ b/extdbms/lib/Services/ServiceService.php
@@ -4,6 +4,7 @@ namespace lib\Services;
use lib\Entities\ServiceEntity as Entity;
use lib\Models\ServiceModel as Model;
+use PDO;
class ServiceService extends CommonService
{
@@ -32,7 +33,8 @@ class ServiceService extends CommonService
$this->getModel()->where('service_code', $key);
return $this->getEntity();
}
- public function getNewServerCount(int $day, array $excepts): int|string
+ //최근 $day일간 신규서비스 카운트
+ public function getLatestCount(int $day, array $excepts): int|string
{
$this->getModel()->where("service_open_date > DATE_ADD(now(), INTERVAL -{$day} DAY)");
$this->getModel()->where("service_status", 'o');
@@ -41,6 +43,7 @@ class ServiceService extends CommonService
// echo __FUNCTION__ . ":" . $this->getModel()->getLastQuery();
return $count;
}
+ //미지급서비스 카운트
public function getUnPaymentCount(array $excepts): int|string
{
$this->getModel()->where("service_payment_date > now()");
@@ -50,34 +53,71 @@ class ServiceService extends CommonService
// echo __FUNCTION__ . ":" . $this->getModel()->getLastQuery();
return $count;
}
-
- private function getTotalCountByDistriction(string $where, string $type, string $switch_code1, string $switch_code2): int
- {
- $this->getModel()->where($where);
- $this->getModel()->where(["service_line" => $type, "service_status" => 'o']);
- $this->getModel()->where("service_sw BETWEEN '{$switch_code1}' AND '{$switch_code2}'");
- $count = $this->getModel()->countAllResults();
- // echo " " . $this->getModel()->getLastQuery();
- return $count;
- }
- final public function getTotalCount(array $siteinfo): array
- {
- $temps = array();
- foreach ($siteinfo['totalcount_customers'] as $customer => $where) {
- $temps[$customer] = [];
- foreach ($siteinfo['totalcount_types'] as $type) {
- $temps[$customer][$type]['Chiba'] = $this->getTotalCountByDistriction($where, $type, 'C00%', 'C64%');
- $temps[$customer][$type]['Tokyo'] = $this->getTotalCountByDistriction($where, $type, 'C80%', 'C99%');
- } //foreach
- // echo var_dump($temps);
- } //foreach
- return $temps;
- }
-
- public function getNews(int $limit): array
+ //최근신규서비스정보 리스트 limit갯수만큼큼
+ public function getLatest(int $limit): array
{
$this->getModel()->orderBy($this->getModel()->getPKField(), 'DESC');
$this->getModel()->limit($limit);
return $this->getEntities();
}
+ //지역(치바,도쿄등)에 따른 DASHBOARD용 서비스 카운트
+ private function getDistrictCountForDashboard(string $where, string $type, array $switchcodes): int
+ {
+ $switchcode_begin = $switchcodes['begin'];
+ $switchcode_end = $switchcodes['end'];
+ $this->getModel()->where($where);
+ $this->getModel()->where(["service_line" => $type, "service_status" => 'o']);
+ $this->getModel()->where("service_sw BETWEEN '{$switchcode_begin}' AND '$switchcode_end'");
+ $count = $this->getModel()->countAllResults();
+ // echo " " . $this->getModel()->getLastQuery();
+ return $count;
+ }
+ final public function getTotalCountForDashboard(array $siteinfo): array
+ {
+ $temps = array();
+ foreach ($siteinfo['totalcount_customers'] as $customer => $where) {
+ $temps[$customer] = [];
+ foreach ($siteinfo['totalcount_types'] as $type) {
+ foreach (DBMS_SERVICE_SWITCHCODE as $district => $switchcodes) {
+ $temps[$customer][$type][$district] = $this->getDistrictCountForDashboard($where, $type, $switchcodes);
+ }
+ } //foreach
+ // echo var_dump($temps);
+ } //foreach
+ return $temps;
+ }
+ //지역(치바,도쿄등)에 따른 사용자별용 서비스 카운트
+ public function getDistrictCountByClient(string $client_code, string $switchcode_begin, string $switchcode_end): int
+ {
+ $this->getModel()->where("client_code", "{$client_code}");
+ $this->getModel()->where("service_sw BETWEEN '{$switchcode_begin}' AND '{$switchcode_end}'");
+ $this->getModel()->where("service_status", "o");
+ $this->getModel()->whereNotIn("service_line", ['normal', 'defence', 'solo', 'test', 'event', 'substitution']);
+ return $this->getCount();
+ // $sql = "SELECT (SELECT COUNT(*) FROM servicedb WHERE service_line = 'normal' AND service_status = 'o' AND service_sw BETWEEN '{$switchcode_begin}' AND '{$switchcode_end}' AND Client_Code = '{$client_code}') AS normal,
+ // (SELECT COUNT(*) FROM servicedb WHERE service_line = 'defence' AND service_status = 'o' AND service_sw BETWEEN '{$switchcode_begin}' AND '{$switchcode_end}' AND Client_Code = '{$client_code}') AS defence,
+ // (SELECT COUNT(*) FROM servicedb WHERE service_line = 'solo' AND service_status = 'o' AND Client_Code = '{$client_code}') AS solo,
+ // (SELECT COUNT(*) FROM servicedb WHERE service_line = 'test' AND service_status = 'o' AND service_sw BETWEEN '{$switchcode_begin}' AND '{$switchcode_end}' AND Client_Code = '{$client_code}') AS test,
+ // (SELECT COUNT(*) FROM servicedb WHERE service_line = 'event' AND service_status = 'o' AND service_sw BETWEEN '{$switchcode_begin}' AND '{$switchcode_end}' AND Client_Code = '{$client_code}') AS event,
+ // (SELECT COUNT(*) FROM servicedb WHERE service_line = 'substitution' AND service_status = 'o' AND service_sw BETWEEN '{$switchcode_begin}' AND '{$switchcode_end}' AND Client_Code = '{$client_code}') AS substitution";
+ // $stmt = $this->getModel()->execute($sql);
+ // // echo " " . $this->getModel()->getLastQuery();
+ // return $stmt->fetch(PDO::FETCH_ASSOC);
+ }
+ //사용자별용 ServieLine별 카운트
+ public function getServiceLineCountByClient(string $client_code, string $service_line): int
+ {
+ $this->getModel()->where("client_code", "{$client_code}");
+ $this->getModel()->where("service_line", "{$service_line}");
+ $this->getModel()->where("service_status", 'o');
+ return $this->getCount();
+ }
+ //사용자별용 서비스 쿠폰
+ public function getCouponCountByClient(string $client_code): int
+ {
+ $this->getModel()->select("SUM(coupon) as coupon");
+ $this->getModel()->where("client_code", "{$client_code}");
+ $this->getModel()->whereNotIn("service_line", ['vpn', 'test', 'solo', 'substitution', 'event']);
+ return $this->getModel()->getResult()['coupon'];
+ }
}
diff --git a/extdbms/lib/Views/dbms/dashboard/totalcount.php b/extdbms/lib/Views/dbms/dashboard/totalcount.php
index 49bd9f5..3390bbc 100644
--- a/extdbms/lib/Views/dbms/dashboard/totalcount.php
+++ b/extdbms/lib/Views/dbms/dashboard/totalcount.php
@@ -41,15 +41,15 @@
totalcount as $company => $service) { ?>
-
+ = $company ?>
$location) { ?>
-
-
+ = $location['Tokyo']; ?>
+ = $location['Chiba']; ?>
-
- summary[$company]['Tokyo'] - $service['test']['Tokyo']; ?>
- summary[$company]['Chiba'] - $service['test']['Chiba']; ?>
- summary[$company]['Tokyo'] - $service['test']['Tokyo'] + $this->summary[$company]['Chiba'] - $service['test']['Chiba']; ?>
+ = $service['test']['Tokyo'] + $service['test']['Chiba']; ?>
+ = $this->summary[$company]['Tokyo'] - $service['test']['Tokyo']; ?>
+ = $this->summary[$company]['Chiba'] - $service['test']['Chiba']; ?>
+ = $this->summary[$company]['Tokyo'] - $service['test']['Tokyo'] + $this->summary[$company]['Chiba'] - $service['test']['Chiba']; ?>
@@ -57,13 +57,13 @@
총합계
siteInfo['totalcount_types'] as $type) { ?>
- summary[$type]['Tokyo']; ?>
- summary[$type]['Chiba']; ?>
+ = $this->summary[$type]['Tokyo']; ?>
+ = $this->summary[$type]['Chiba']; ?>
- summary['test']['Tokyo'] + $this->summary['test']['Chiba']; ?>
- total['Tokyo'] - $this->summary['test']['Tokyo']; ?>
- total['Chiba'] - $this->summary['test']['Chiba']; ?>
- total['Tokyo'] - $this->summary['test']['Tokyo'] + $this->total['Chiba'] - $this->summary['test']['Chiba']; ?>
+ = $this->summary['test']['Tokyo'] + $this->summary['test']['Chiba']; ?>
+ = $this->total['Tokyo'] - $this->summary['test']['Tokyo']; ?>
+ = $this->total['Chiba'] - $this->summary['test']['Chiba']; ?>
+ = $this->total['Tokyo'] - $this->summary['test']['Tokyo'] + $this->total['Chiba'] - $this->summary['test']['Chiba']; ?>
\ No newline at end of file
diff --git a/extdbms/lib/Views/dbms/service/dashboard.php b/extdbms/lib/Views/dbms/service/dashboard.php
new file mode 100644
index 0000000..3e26829
--- /dev/null
+++ b/extdbms/lib/Views/dbms/service/dashboard.php
@@ -0,0 +1,56 @@
+
+
+
+
+ 도쿄
+ 치바
+ VPN
+
+
+
+
+ = $this->totalcount['Tokyo'] ?>
+ = $this->totalcount['Chiba'] ?>
+ = $this->totalcount['vpn'] ?>
+
+
+
+
+
+
+
+
+ 일반
+ 방어
+ 전용
+ 이벤트
+
+
+
+
+ = $this->totalcount['normal'] ?>
+ = $this->totalcount['defence'] ?>
+ = $this->totalcount['solo'] ?>
+ = $this->totalcount['event'] ?>
+
+
+
+
+
+
+
+
+ 테스트
+ 대체
+ 쿠폰
+
+
+
+
+ = $this->totalcount['test'] ?>
+ = $this->totalcount['substitution'] ?>
+ = $this->totalcount['coupon'] ?>
+
+
+
+
\ No newline at end of file
diff --git a/idcproject/WebContent/IDC/Navigation.jsp b/idcproject/WebContent/IDC/Navigation.jsp
index 2bfb749..810fe8a 100644
--- a/idcproject/WebContent/IDC/Navigation.jsp
+++ b/idcproject/WebContent/IDC/Navigation.jsp
@@ -1,6 +1,7 @@
<%@ page language="java" contentType="text/html; charset=UTF-8" pageEncoding="UTF-8"%>
<%@ taglib prefix="c" uri="http://java.sun.com/jsp/jstl/core" %>
<% pageContext.setAttribute("phpurl",request.getScheme()+"://"+request.getServerName()); %>
+<% pageContext.setAttribute("host",request.getServerName()); %>
@@ -98,79 +99,79 @@ $(function()
});
-//사이트 Logo 출력용
-function getSiteID(){
- switch(location.hostname){
- case 'dbms.prime-idc.jp':
- return 'PrimeIDC';
- break;
- case 'dbms.itsolution-idc.jp':
- return 'ITSolution';
- break;
- case 'dbms.gdidc.jp':
- return 'GDIDC';
- break;
- default:
- alert("getSiteID 오류:"+location.hostname);
- return false;
- break;
- }
-};
-//사이트 메일 출력용
-function getSiteSupport(){
- switch(location.hostname){
- case 'dbms.prime-idc.jp':
- return 'support@prime-idc.jp';
- break;
- case 'dbms.itsolution-idc.jp':
- return 'support@itsolution-idc.jp';
- break;
- case 'dbms.gdidc.jp':
- return 'support@gdidc.jp';
- break;
- default:
- alert("getSiteSupport 오류:"+location.hostname);
- return false;
- break;
- }
-};
-//입금은행 출력용
-function getSiteBank(){
- switch(location.hostname){
- case 'dbms.prime-idc.jp':
- return '국민 농협 우리 신한 작업용 입금의 경우 Primeidc ';
- break;
- case 'dbms.itsolution-idc.jp':
- return '우리 새마을 농협 국민 작업용 입금의 경우 Itsolution ';
- break;
- case 'dbms.gdidc.jp':
- return '우리 작업용 입금의 경우 GDIDC ';
- break;
- default:
- alert("getSiteBank 오류:"+location.hostname);
- return false;
- break;
- }
+// //사이트 Logo 출력용
+// function getSiteID(){
+// switch(location.hostname){
+// case 'dbms.prime-idc.jp':
+// return 'PrimeIDC';
+// break;
+// case 'dbms.itsolution-idc.jp':
+// return 'ITSolution';
+// break;
+// case 'dbms.gdidc.jp':
+// return 'GDIDC';
+// break;
+// default:
+// alert("getSiteID 오류:"+location.hostname);
+// return false;
+// break;
+// }
+// };
+// //사이트 메일 출력용
+// function getSiteSupport(){
+// switch(location.hostname){
+// case 'dbms.prime-idc.jp':
+// return 'support@prime-idc.jp';
+// break;
+// case 'dbms.itsolution-idc.jp':
+// return 'support@itsolution-idc.jp';
+// break;
+// case 'dbms.gdidc.jp':
+// return 'support@gdidc.jp';
+// break;
+// default:
+// alert("getSiteSupport 오류:"+location.hostname);
+// return false;
+// break;
+// }
+// };
+// //입금은행 출력용
+// function getSiteBank(){
+// switch(location.hostname){
+// case 'dbms.prime-idc.jp':
+// return '국민 농협 우리 신한 작업용 입금의 경우 Primeidc ';
+// break;
+// case 'dbms.itsolution-idc.jp':
+// return '우리 새마을 농협 국민 작업용 입금의 경우 Itsolution ';
+// break;
+// case 'dbms.gdidc.jp':
+// return '우리 작업용 입금의 경우 GDIDC ';
+// break;
+// default:
+// alert("getSiteBank 오류:"+location.hostname);
+// return false;
+// break;
+// }
-};
+// };
-//Loading이 완료후 필요한 작업 실행용
-window.onload = function(){
- site_id = getSiteID();
- site_support = getSiteSupport();
- site_bank = getSiteBank();
+// //Loading이 완료후 필요한 작업 실행용
+// window.onload = function(){
+// site_id = getSiteID();
+// site_support = getSiteSupport();
+// site_bank = getSiteBank();
- if(document.getElementById('SiteLogo')){
- document.getElementById('SiteLogo').innerHTML=site_id;
- }
- if(document.getElementById('SiteSupport')){
- document.getElementById('SiteSupport').innerHTML=site_support;
- document.getElementById('SiteSupportTitle').innerHTML=site_id;
- }
- if(document.getElementById('SiteBank')){
- document.getElementById('SiteBank').innerHTML=site_bank;
- }
-}
+// if(document.getElementById('SiteLogo')){
+// document.getElementById('SiteLogo').innerHTML=site_id;
+// }
+// if(document.getElementById('SiteSupport')){
+// document.getElementById('SiteSupport').innerHTML=site_support;
+// document.getElementById('SiteSupportTitle').innerHTML=site_id;
+// }
+// if(document.getElementById('SiteBank')){
+// document.getElementById('SiteBank').innerHTML=site_bank;
+// }
+// }
diff --git a/extdbms/lib/Controllers/DBMS/DashboardController.php b/extdbms/lib/Controllers/DBMS/DashboardController.php
index 159083a..58de243 100644
--- a/extdbms/lib/Controllers/DBMS/DashboardController.php
+++ b/extdbms/lib/Controllers/DBMS/DashboardController.php
@@ -61,15 +61,15 @@ class DashboardController extends BaseController
return $this->_historyService;
}
//Dashboard , default_alert.php
- //CLI 접속방법 : php index.php SiteController/dashboard
- //WEB 접속방법 : http://localhost/SiteController/dashboard
+ //CLI 접속방법 : php index.php site/dashboard/topboard
+ //WEB 접속방법 : http://localhost/site/dashboard/topboard
public function topboard()
{
// 최근7일 신규서버수
//예외,service_line = "test","substitution"
$excepts = ["test", "substitution"];
$this->day = intval($_ENV['SITE_DASHBOARD_DAY'] ?? $_SERVER['SITE_DASHBOARD_DAY'] ?? 7);
- $this->newServers = $this->getServiceService()->getNewServerCount($this->day, $excepts);
+ $this->newServers = $this->getServiceService()->getLatestCount($this->day, $excepts);
// 금일기준 미납서버수
//예외,service_line = "test","substitution",C012:게임윙,C116:WinIDC,C219:IDC-JP
$excepts = ["test", "substitution", 'C116', 'C012', 'C219'];
@@ -78,8 +78,8 @@ class DashboardController extends BaseController
}
//서비스카운팅 , total_counting.php
//CLI 접속방법 : php index.php site/totalcount/sitekey/dbms.prime-idc.jp
//WEB 접속방법 : http://localhost/site/totalcount/sitekey/dbms.prime-idc.jp
public function totalcount(mixed $sitekey = null)
{
if ($sitekey === null) {
@@ -90,7 +90,7 @@ class DashboardController extends BaseController
}
//사이트 정보 가져오기
$this->siteInfo = DBMS_SITEINFOS[$sitekey];
- $this->totalcount = $this->getServiceService()->getTotalCount($this->siteInfo);
+ $this->totalcount = $this->getServiceService()->getTotalCountForDashboard($this->siteInfo);
$summary = array();
foreach ($this->siteInfo['totalcount_types'] as $type) {
$summary[$type] = array("Tokyo" => 0, "Chiba" => 0);
@@ -114,13 +114,13 @@ class DashboardController extends BaseController
return $this->render(__FUNCTION__);
}
//신규서버현황 new_server_list.php
//CLI 접속방법 : php index.php SiteController/newservices/limit/5
//WEB 접속방법 : http://localhost/SiteController/newservices/limit/5
public function latest_service(mixed $limit = 5)
{
//신규서버정보
$this->limit = intval($limit);
- $this->entities = $this->getServiceService()->getNews($this->limit);
+ $this->entities = $this->getServiceService()->getLatest($this->limit);
// echo $this->getServiceervice()->getModel()->getLastQuery();
//전체 관리자정보(등록자)
$this->users = $this->getMemberService()->getEntities();
@@ -148,13 +148,13 @@ class DashboardController extends BaseController
$this->kcss = $kcss;
return $this->render(__FUNCTION__);
}
//CLI 접속방법 : php index.php SiteController/newhistorys/limit/5
//WEB 접속방법 : http://localhost/SiteController/newhistorys/limit/5
public function latest_history(mixed $limit = 5): string
{
//신규서버정보
$this->limit = intval($limit);
- $this->entitys = $this->getHistoryService()->getNews($this->limit);
+ $this->entitys = $this->getHistoryService()->getLatest($this->limit);
//전체 서비스정보
$this->services = $this->getServiceService()->getEntities();
//services 고객정보
@@ -78,8 +78,8 @@ class DashboardController extends BaseController
}
//서비스카운팅 , total_counting.php
- //CLI 접속방법 : php index.php site/totalcount/sitekey/dbms.prime-idc.jp
- //WEB 접속방법 : http://localhost/site/totalcount/sitekey/dbms.prime-idc.jp
+ //CLI 접속방법 : php index.php site/dashboard/totalcount/sitekey/도메인
+ //WEB 접속방법 : http://localhost/site/dashboard/totalcount/sitekey/도메인
public function totalcount(mixed $sitekey = null)
{
@@ -114,13 +114,13 @@ class DashboardController extends BaseController
}
//신규서버현황 new_server_list.php
- //CLI 접속방법 : php index.php SiteController/newservices/limit/5
- //WEB 접속방법 : http://localhost/SiteController/newservices/limit/5
+ //CLI 접속방법 : php index.php site/dashboard/latest_service/limit/5
+ //WEB 접속방법 : http://localhost/site/dashboard/latest_service/limit/5
public function latest_service(mixed $limit = 5)
{
@@ -148,13 +148,13 @@ class DashboardController extends BaseController
return $this->render(__FUNCTION__);
}
- //CLI 접속방법 : php index.php SiteController/newhistorys/limit/5
- //WEB 접속방법 : http://localhost/SiteController/newhistorys/limit/5
+ //CLI 접속방법 : php index.php site/dashboard/latest_history/limit/5
+ //WEB 접속방법 : http://localhost/site/dashboard/latest_history/limit/5
public function latest_history(mixed $limit = 5): string
{
diff --git a/extdbms/lib/Controllers/DBMS/ServiceController.php b/extdbms/lib/Controllers/DBMS/ServiceController.php
index 6cd34b3..af5e5c9 100644
--- a/extdbms/lib/Controllers/DBMS/ServiceController.php
+++ b/extdbms/lib/Controllers/DBMS/ServiceController.php
@@ -31,9 +31,38 @@ class ServiceController extends BaseController
return $this->_addDbService;
}
+ //서비스카운팅 , total_counting_customer.php
+ //CLI 접속방법 : php index.php site/service/totalcount/client_code/코드번호
+ //WEB 접속방법 : http://localhost/site/service/totalcount/client_code/코드번호
+ public function dashboard(mixed $client_code = null)
+ {
+ if ($client_code === null) {
+ $client_code = $this->getSegments('client_code');
+ if ($client_code === null) {
+ throw new \Exception("client_code 값이 정의되지 않았습니다.");
+ }
+ }
+ $this->client_code = $client_code;
+ $dashboard = [];
+ foreach (DBMS_SERVICE_SWITCHCODE as $district => $switchcodes) {
+ $switchcode_begin = $switchcodes['begin'];
+ $switchcode_end = $switchcodes['end'];
+ $dashboard[$district] = $this->getServiceService()->getDistrictCountByClient(
+ $client_code,
+ $switchcode_begin,
+ $switchcode_end
+ );
+ } //foreach
+ foreach (array_keys(DBMS_SERVICE_LINE) as $service_line) {
+ $dashboard[$service_line] = $this->getServiceService()->getServiceLineCountByClient($client_code, $service_line);
+ } //foreach
+ $dashboard['coupon'] = $this->getServiceService()->getCouponCountByClient($client_code);
+ $this->dashboard = $dashboard;
+ return $this->render(__FUNCTION__);
+ }
//부가서비스 : 닷디펜더,딥파인더 등, deepfinder_list.php,dotdefender_list.php
//CLI 접속방법 : php index.php SiteController/extraservice/client_code/코드번호
//WEB 접속방법 : http://localhost/SiteController/extraservice/sitekey/dbms.prime-idc.jp/client_code/코드번호
public function extra(mixed $adddb_code = null): string
{
if ($adddb_code === null) {
@@ -31,9 +31,38 @@ class ServiceController extends BaseController
//부가서비스 : 닷디펜더,딥파인더 등, deepfinder_list.php,dotdefender_list.php
- //CLI 접속방법 : php index.php SiteController/extraservice/client_code/코드번호
- //WEB 접속방법 : http://localhost/SiteController/extraservice/sitekey/dbms.prime-idc.jp/client_code/코드번호
+ //CLI 접속방법 : php index.php site/service//extra/adddb_code/코드번호
+ //WEB 접속방법 : http://localhost/site/service/extra/adddb_code/코드번호
public function extra(mixed $adddb_code = null): string
{